/*  PCSX2 - PS2 Emulator for PCs
 *  Copyright (C) 2002-2020  PCSX2 Dev Team
 *
 *  PCSX2 is free software: you can redistribute it and/or modify it under the terms
 *  of the GNU Lesser General Public License as published by the Free Software Found-
 *  ation, either version 3 of the License, or (at your option) any later version.
 *
 *  PCSX2 is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 *  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *  PURPOSE.  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with PCSX2.
 *  If not, see <http://www.gnu.org/licenses/>.
 */

#include "osdebugout.h"

std::wostream& operator<<(std::wostream& os, const std::string& s)
{
	std::wstring ws;
	ws.assign(s.begin(), s.end());
	return os << ws;
}

#ifdef _WIN32
static int rateLimit = 0;
void _OSDebugOut(const TCHAR* psz_fmt, ...)
{
	if (rateLimit > 0 && rateLimit < 100)
	{
		rateLimit++;
		return;
	}
	else
	{
		//rateLimit = 1;
	}

	va_list args;
	va_start(args, psz_fmt);

#ifdef UNICODE
	int bufsize = _vscwprintf(psz_fmt, args) + 1;
	std::vector<WCHAR> msg(bufsize);
	vswprintf_s(&msg[0], bufsize, psz_fmt, args);
#else
	int bufsize = _vscprintf(psz_fmt, args) + 1;
	std::vector<char> msg(bufsize);
	vsprintf_s(&msg[0], bufsize, psz_fmt, args);
#endif

	//_vsnwprintf_s(&msg[0], bufsize, bufsize-1, psz_fmt, args);
	va_end(args);
	//static FILE *hfile = nullptr;
	//if (!hfile) {
	//	hfile = _wfopen(L"USBqemu-wheel.log", L"wb,ccs=UNICODE");
	//	if (!hfile) throw std::runtime_error("ass");
	//}
	//else
	//	fwprintf(hfile, L"%s", &msg[0]);
	OutputDebugString(&msg[0]);
}
#endif
